<?php
/**
 * @file
 * Author Pane Popup admin configurations.
 */

/**
 * Callback function for admin setting.
 */
function author_pane_popup_admin() {
  $content_types = node_type_get_types();
  $form['author_pane_popup'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select the content types you want to enable author pane popup.'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  foreach ($content_types as $content_type) {
    $author_pane_popup_content_types[$content_type->type] = $content_type->name;
  }
  $form['author_pane_popup']['author_pane_popup_content_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Enable Tracking'),
    '#options' => $author_pane_popup_content_types,
  );
  $form['author_pane_popup']['author_pane_popup_content_types']['#default_value'] = array_keys(array_filter(variable_get('author_pane_popup_content_types', $form['author_pane_popup']['author_pane_popup_content_types']['#options'])));
  $qtip_instances = qtip_load_multiple();
  $qtip_instances_ops[''] = '-Select-';
  foreach ($qtip_instances as $key => $instance) {
    $qtip_instances_ops[$key] = $instance->name;
  }
  $form['author_pane_popup_style'] = array(
    '#type' => 'fieldset',
    '#title' => t('qTip instances'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['author_pane_popup_style']['author_pane_popup_qtip_instance'] = array(
    '#type' => 'select',
    '#options' => $qtip_instances_ops,
    '#default_value' => variable_get('author_pane_popup_qtip_instance', ''),
    '#description' => t('Select the qTip style to use for your Author Pane Popup. !click_here to add new qTip instances.', array('!click_here' => l(t('Click here'), 'admin/config/user-interface/qtip/list/add'))),
    '#required' => TRUE,
  );
  // Page specific visibility configurations.
  $php_access = user_access('use PHP for Author Pane Popup visibility');
  $visibility = variable_get('author_pane_popup_visibility_options', 0);
  $pages = variable_get('author_pane_popup_visibility_pages', AUTHOR_PANE_POPUP_PAGES);
  $options = array();
  $title = '';
  $description = '';
  if ($visibility == AUTHOR_PANE_POPUP_USE_PHP_FOR_TRACKING && !$php_access) {
    $form['author_pane_popup_visibility_options'] = array('#type' => 'value', '#value' => 1);
    $form['author_pane_popup_visibility_pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(
      t('Every page except the listed pages'),
      t('The listed pages only'),
    );
    $description = t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array(
      '%blog' => 'blog',
      '%blog-wildcard' => 'blog/*',
      '%front' => '<front>',
    ));
    if (module_exists('php') && $php_access) {
      $options[] = t('Pages on which this PHP code returns <code>TRUE</code> (experts only)');
      $title = t('Pages or PHP code');
      $description .= ' ' . t('If the PHP option is chosen, enter PHP code between %php. Note that executing incorrect PHP code can break your Drupal site.', array('%php' => '<?php ?>'));
    }
    else {
      $title = t('Pages');
    }
  }
  $form['author_pane_popup_visibility'] = array(
    '#type' => 'fieldset',
    '#title' => t('Add Author Pane Popup to specific pages'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['author_pane_popup_visibility']['author_pane_popup_visibility_options'] = array(
    '#type' => 'radios',
    '#options' => $options,
    '#default_value' => variable_get('author_pane_popup_visibility_options', 0),
  );
  $form['author_pane_popup_visibility']['author_pane_popup_visibility_pages'] = array(
    '#type' => 'textarea',
    '#title' => $title,
    '#default_value' => $pages,
    '#description' => $description,
    '#wysiwyg' => FALSE,
    '#rows' => 10,
  );
  return system_settings_form($form);
}
